@@ -7,12 +7,12 @@
 #include <time.h>
 
 #include <check.h>
-#include "../include/orcania.h"
+#include "orcania.h"
 
 START_TEST(test_o_malloc)
 {
   void * var;
-  var = malloc(8);
+  var = o_malloc(8);
   ck_assert_ptr_ne(var, NULL);
   o_free(var);
 }
@@ -21,11 +21,13 @@ END_TEST
 START_TEST(test_o_realloc)
 {
   void * var;
-  var = malloc(8);
+  var = o_malloc(8);
   ck_assert_ptr_ne(var, NULL);
-  var = realloc(var, 16);
+  var = o_realloc(var, 16);
   ck_assert_ptr_ne(var, NULL);
-  o_free(var);
+  if (var != NULL) {
+    o_free(var);
+  }
 }
 END_TEST
 
